% SCRIPT to ILLUSTRATE UTILITY of the SIMULATION TOOL;
% -------------------------------------------------------------------------
% it reproduces the results from Zhang and Rosenberger (2007) who used the 
% DBCD procedure with Weibull time-to-event outcomes to redesign a phase III 
% survival trial in metastatic breast cancer originally reported by Jones, 
% Erban, Overmoyer, Budd, Hutchings, Lower, Laufman, Sundaram, Urba, Pritchard, 
% Mennel, Richards,Olsen, Meyers, and Ravdin (2005)
% -------------------------------------------------------------------------

% initialization of simulation options
   rspdistr = 'Weibull';             % time-to-event distribution
        trt = 2;                     % number of treatments
        sbj = 449;                   % number of patients involved in the trial
       sbj0 = 20;                    % number of patients randomized with CRD
     cohort = 20;                    % number of patients in the cohort
        sim = 1000;                  % number of simulation
     design = 'Zhang-Rosenberger-1'; % design applied
    options = [1.1, 0.64, 0.93];     % Weibull distr. options
                                     % (mu1 = 1.1, mu2 = 0.64, b = 0.93)
          R = 84;                    % recruitment period time
          D = 102;                   % trial duration time
  isdelayed = 1;                     % responses are delayed
  
% setup simulated trial
  trial = trsetup(rspdistr, options, design, 'all', [], R, D, [], [], ...
      trt, sbj, sbj0, cohort, 'DBCD', sim, [], 1); 
% simulate trial 
  tr = trsimulate(trial);
% display results
  sep = '------------------------------------------------------------------------------------\n';
  fprintf(sep);
  fprintf('|             Time-to-event distribution: %s%s |\n', rspdistr, blanks(33))
  fprintf('|     Time-to-event distribution options: mu = (%4.2f, %4.2f), b = %4.2f%s |\n', options, blanks(13))
  fprintf('|                   Number of treatments: %i%s |\n', trt, blanks(39))
  fprintf('|                     Number of patients: %i%s |\n', sbj, blanks(37))
  fprintf('| Number of patients randomized with CRD: %i%s |\n', sbj0, blanks(38))
  fprintf('|           Number of patients in cohort: %i%s |\n', cohort, blanks(38))
  fprintf('|                  Number of simulations: %i%s |\n', sim, blanks(36))
  fprintf('|                     Recruitment period: %i%s |\n', R, blanks(38))
  fprintf('|                         Trial duration: %i%s |\n', D, blanks(37))
  fprintf('|     Delayed response (1 = YES, 0 = NO): %i%s |\n', isdelayed, blanks(39))
  
  fprintf(sep);
  fprintf('| Characteristic |   Theoretical    |     Average      |     Std. dev     | Median |\n' )
  fprintf(sep);
  fprintf('|  (rho1, rho2)  | (%6.4f, %6.4f) | (%6.4f, %6.4f) | (%6.4f, %6.4f) |        |\n', ...
      tr.ta, mean(mean(tr.TRT), 3), std(mean(tr.TRT), [], 3));
  fprintf('|  ( mu1,  mu2)  | (%6.4f, %6.4f) | (%6.4f, %6.4f) | (%6.4f, %6.4f) |        |\n', ...
      tr.opt(1:end - 1), mean(tr.optmle(end, 1:end-1, :), 3), std(tr.optmle(end, 1:end-1, :), [], 3));
  fprintf('|            b   |          %6.4f  |          %6.4f  |          %6.4f  |        |\n', ...
      tr.opt(end), mean(tr.optmle(end, end, :), 3), std(tr.optmle(end, end, :), [], 3));
  fprintf('|             TT |                  |         %7.1f  |         %7.1f  |%7.1f |\n', ...
      mean(tr.TT), std(tr.TT), median(tr.TT));
  fprintf('|   D-efficiency |          %6.4f  |                  |                  | %6.4f |\n', ...
      tr.eff.th(1), median(tr.eff.sim(:, 1)));
  fprintf('| D-A-efficiency |          %6.4f  |                  |                  | %6.4f |\n', ...
      tr.eff.th(2), median(tr.eff.sim(:, 2)));
  fprintf('|  HR-efficiency |          %6.4f  |                  |                  | %6.4f |\n', ...
      tr.eff.th(3), median(tr.eff.sim(:, 3)));
  fprintf('|            THR |          %6.4f  |          %6.4f  |          %6.4f  | %6.4f |\n', ...
      tr.THR.th, mean(tr.THR.sim), std(tr.THR.sim), median(tr.THR.sim));
  fprintf('|           prop |                  |          %6.4f  |          %6.4f  |        |\n', ...
      mean(tr.prop), std(tr.prop));
  fprintf(sep)
